==> haskell-bencode-0.6.0.0-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-HBc3tM0X7PyLq6QAzouta9
key: bencode-0.6.0.0-HBc3tM0X7PyLq6QAzouta9
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: 0147086266a19ff7c7cdd296872e122f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/bencode-0.6.0.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-HBc3tM0X7PyLq6QAzouta9
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.0.0-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-9qBY6Ybs1RqCYlxCFJjDi9
key: bencode-0.6.0.0-9qBY6Ybs1RqCYlxCFJjDi9
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: b53a17f38b1a2fa1d72464e43bd3f046
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/bencode-0.6.0.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-9qBY6Ybs1RqCYlxCFJjDi9
depends:
    base-4.9.0.0 binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
